Tutorial — gensim documentation

### Navigation

- index
- modules |
- next |
- previous |
- gensim documentation »

# Tutorial

This tutorial is organized as a series of examples that highlight various features of gensim. It is assumed that the reader is familiar with the Python language and has read the Introduction.

The examples are divided into parts on:

- Corpora and the Vector Space Model

### Navigation

- index
- modules |
- next |
- previous |
- gensim documentation »